@@ -1,8 +1,3 @@
-###########################
-# Author : Jeff Mo
-# Date : 01/04/2009
-# Version : 1.0
-###########################
 package App::Cinema::Controller::Menu;
 
 use strict;
@@ -11,9 +6,7 @@ use base 'Catalyst::Controller';
 
 sub index : Private {
 	my ( $self, $c ) = @_;
-
-	my $result =
-	  $c->model('MD::Item')
+	my $result = $c->model('MD::Item')
 	  ->search( undef, { rows => 3, order_by => { -desc => 'release_date' } } );
 	$c->stash->{items}    = $result;
 	$c->stash->{template} = "menu.tt2";
